About pydae
===========

Overview
--------

**pydae** is an open source collection of Python subroutines for generation, solution and analysis of Differential Algebraic Equations (DAE) systems.

pydae combines cutting edge technologies like Python JIT compiling
(using numba) with the symbolic module (sympy) to provide a user friendly API for solving nonlinear DAE problems. 

pydae is oriented to the analysis of power systems problems but it can be used in other fields that requires a DAE solution enviroment.

Since I have only solved easy academic problems I cannot assess the
suitability of the library for professional environments.
